==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/InlineHookOAuthBasicConfig.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookChannelConfigAuthScheme;
import com.okta.sdk.resource.model.InlineHookChannelConfigHeaders;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InlineHookOAuthBasicConfig
 */
@JsonPropertyOrder({ InlineHookOAuthBasicConfig.JSON_PROPERTY_AUTH_TYPE,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_CLIENT_ID, InlineHookOAuthBasicConfig.JSON_PROPERTY_SCOPE,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_TOKEN_URL, InlineHookOAuthBasicConfig.JSON_PROPERTY_AUTH_SCHEME,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_HEADERS, InlineHookOAuthBasicConfig.JSON_PROPERTY_METHOD,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_URI })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class InlineHookOAuthBasicConfig implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUTH_TYPE = "authType";
    private String authType;

    public static final String JSON_PROPERTY_CLIENT_ID = "clientId";
    private String clientId;

    public static final String JSON_PROPERTY_SCOPE = "scope";
    private String scope;

    public static final String JSON_PROPERTY_TOKEN_URL = "tokenUrl";
    private String tokenUrl;

    public static final String JSON_PROPERTY_AUTH_SCHEME = "authScheme";
    private InlineHookChannelConfigAuthScheme authScheme;

    public static final String JSON_PROPERTY_HEADERS = "headers";
    private List<InlineHookChannelConfigHeaders> headers = null;

    public static final String JSON_PROPERTY_METHOD = "method";
    private String method;

    public static final String JSON_PROPERTY_URI = "uri";
    private String uri;

    public InlineHookOAuthBasicConfig() {
    }

    public InlineHookOAuthBasicConfig authType(String authType) {

        this.authType = authType;
        return this;
    }

    /**
     * Get authType
     *
     * @return authType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAuthType() {
        return authType;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthType(String authType) {
        this.authType = authType;
    }

    public InlineHookOAuthBasicConfig clientId(String clientId) {

        this.clientId = clientId;
        return this;
    }

    /**
     * Get clientId
     *
     * @return clientId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getClientId() {
        return clientId;
    }

    @JsonProperty(JSON_PROPERTY_CLIENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClientId(String clientId) {
        this.clientId = clientId;
    }

    public InlineHookOAuthBasicConfig scope(String scope) {

        this.scope = scope;
        return this;
    }

    /**
     * Get scope
     *
     * @return scope
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getScope() {
        return scope;
    }

    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScope(String scope) {
        this.scope = scope;
    }

    public InlineHookOAuthBasicConfig tokenUrl(String tokenUrl) {

        this.tokenUrl = tokenUrl;
        return this;
    }

    /**
     * Get tokenUrl
     *
     * @return tokenUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TOKEN_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTokenUrl() {
        return tokenUrl;
    }

    @JsonProperty(JSON_PROPERTY_TOKEN_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTokenUrl(String tokenUrl) {
        this.tokenUrl = tokenUrl;
    }

    public InlineHookOAuthBasicConfig authScheme(InlineHookChannelConfigAuthScheme authScheme) {

        this.authScheme = authScheme;
        return this;
    }

    /**
     * Get authScheme
     *
     * @return authScheme
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_SCHEME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookChannelConfigAuthScheme getAuthScheme() {
        return authScheme;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_SCHEME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthScheme(InlineHookChannelConfigAuthScheme authScheme) {
        this.authScheme = authScheme;
    }

    public InlineHookOAuthBasicConfig headers(List<InlineHookChannelConfigHeaders> headers) {

        this.headers = headers;
        return this;
    }

    public InlineHookOAuthBasicConfig addheadersItem(InlineHookChannelConfigHeaders headersItem) {
        if (this.headers == null) {
            this.headers = new ArrayList<>();
        }
        this.headers.add(headersItem);
        return this;
    }

    /**
     * Get headers
     *
     * @return headers
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HEADERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<InlineHookChannelConfigHeaders> getHeaders() {
        return headers;
    }

    @JsonProperty(JSON_PROPERTY_HEADERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHeaders(List<InlineHookChannelConfigHeaders> headers) {
        this.headers = headers;
    }

    public InlineHookOAuthBasicConfig method(String method) {

        this.method = method;
        return this;
    }

    /**
     * Get method
     *
     * @return method
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMethod() {
        return method;
    }

    @JsonProperty(JSON_PROPERTY_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMethod(String method) {
        this.method = method;
    }

    public InlineHookOAuthBasicConfig uri(String uri) {

        this.uri = uri;
        return this;
    }

    /**
     * Get uri
     *
     * @return uri
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_URI)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getUri() {
        return uri;
    }

    @JsonProperty(JSON_PROPERTY_URI)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUri(String uri) {
        this.uri = uri;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineHookOAuthBasicConfig inlineHookOAuthBasicConfig = (InlineHookOAuthBasicConfig) o;
        return Objects.equals(this.authType, inlineHookOAuthBasicConfig.authType)
                && Objects.equals(this.clientId, inlineHookOAuthBasicConfig.clientId)
                && Objects.equals(this.scope, inlineHookOAuthBasicConfig.scope)
                && Objects.equals(this.tokenUrl, inlineHookOAuthBasicConfig.tokenUrl)
                && Objects.equals(this.authScheme, inlineHookOAuthBasicConfig.authScheme)
                && Objects.equals(this.headers, inlineHookOAuthBasicConfig.headers)
                && Objects.equals(this.method, inlineHookOAuthBasicConfig.method)
                && Objects.equals(this.uri, inlineHookOAuthBasicConfig.uri);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(authType, clientId, scope, tokenUrl, authScheme, headers, method, uri);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InlineHookOAuthBasicConfig {\n");
        sb.append("    authType: ").append(toIndentedString(authType)).append("\n");
        sb.append("    clientId: ").append(toIndentedString(clientId)).append("\n");
        sb.append("    scope: ").append(toIndentedString(scope)).append("\n");
        sb.append("    tokenUrl: ").append(toIndentedString(tokenUrl)).append("\n");
        sb.append("    authScheme: ").append(toIndentedString(authScheme)).append("\n");
        sb.append("    headers: ").append(toIndentedString(headers)).append("\n");
        sb.append("    method: ").append(toIndentedString(method)).append("\n");
        sb.append("    uri: ").append(toIndentedString(uri)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/InlineHookOAuthBasicConfig.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.InlineHookChannelConfigAuthScheme;
import com.okta.sdk.resource.model.InlineHookChannelConfigHeaders;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * InlineHookOAuthBasicConfig
 */
@JsonPropertyOrder({ InlineHookOAuthBasicConfig.JSON_PROPERTY_AUTH_TYPE,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_CLIENT_ID, InlineHookOAuthBasicConfig.JSON_PROPERTY_SCOPE,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_TOKEN_URL, InlineHookOAuthBasicConfig.JSON_PROPERTY_AUTH_SCHEME,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_HEADERS, InlineHookOAuthBasicConfig.JSON_PROPERTY_METHOD,
        InlineHookOAuthBasicConfig.JSON_PROPERTY_URI })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class InlineHookOAuthBasicConfig implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_AUTH_TYPE = "authType";
    private String authType;

    public static final String JSON_PROPERTY_CLIENT_ID = "clientId";
    private String clientId;

    public static final String JSON_PROPERTY_SCOPE = "scope";
    private String scope;

    public static final String JSON_PROPERTY_TOKEN_URL = "tokenUrl";
    private String tokenUrl;

    public static final String JSON_PROPERTY_AUTH_SCHEME = "authScheme";
    private InlineHookChannelConfigAuthScheme authScheme;

    public static final String JSON_PROPERTY_HEADERS = "headers";
    private List<InlineHookChannelConfigHeaders> headers = null;

    public static final String JSON_PROPERTY_METHOD = "method";
    private String method;

    public static final String JSON_PROPERTY_URI = "uri";
    private String uri;

    public InlineHookOAuthBasicConfig() {
    }

    public InlineHookOAuthBasicConfig authType(String authType) {

        this.authType = authType;
        return this;
    }

    /**
     * Get authType
     *
     * @return authType
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAuthType() {
        return authType;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthType(String authType) {
        this.authType = authType;
    }

    public InlineHookOAuthBasicConfig clientId(String clientId) {

        this.clientId = clientId;
        return this;
    }

    /**
     * Get clientId
     *
     * @return clientId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CLIENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getClientId() {
        return clientId;
    }

    @JsonProperty(JSON_PROPERTY_CLIENT_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setClientId(String clientId) {
        this.clientId = clientId;
    }

    public InlineHookOAuthBasicConfig scope(String scope) {

        this.scope = scope;
        return this;
    }

    /**
     * Get scope
     *
     * @return scope
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getScope() {
        return scope;
    }

    @JsonProperty(JSON_PROPERTY_SCOPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setScope(String scope) {
        this.scope = scope;
    }

    public InlineHookOAuthBasicConfig tokenUrl(String tokenUrl) {

        this.tokenUrl = tokenUrl;
        return this;
    }

    /**
     * Get tokenUrl
     *
     * @return tokenUrl
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TOKEN_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getTokenUrl() {
        return tokenUrl;
    }

    @JsonProperty(JSON_PROPERTY_TOKEN_URL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTokenUrl(String tokenUrl) {
        this.tokenUrl = tokenUrl;
    }

    public InlineHookOAuthBasicConfig authScheme(InlineHookChannelConfigAuthScheme authScheme) {

        this.authScheme = authScheme;
        return this;
    }

    /**
     * Get authScheme
     *
     * @return authScheme
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_AUTH_SCHEME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public InlineHookChannelConfigAuthScheme getAuthScheme() {
        return authScheme;
    }

    @JsonProperty(JSON_PROPERTY_AUTH_SCHEME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAuthScheme(InlineHookChannelConfigAuthScheme authScheme) {
        this.authScheme = authScheme;
    }

    public InlineHookOAuthBasicConfig headers(List<InlineHookChannelConfigHeaders> headers) {

        this.headers = headers;
        return this;
    }

    public InlineHookOAuthBasicConfig addheadersItem(InlineHookChannelConfigHeaders headersItem) {
        if (this.headers == null) {
            this.headers = new ArrayList<>();
        }
        this.headers.add(headersItem);
        return this;
    }

    /**
     * Get headers
     *
     * @return headers
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_HEADERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<InlineHookChannelConfigHeaders> getHeaders() {
        return headers;
    }

    @JsonProperty(JSON_PROPERTY_HEADERS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setHeaders(List<InlineHookChannelConfigHeaders> headers) {
        this.headers = headers;
    }

    public InlineHookOAuthBasicConfig method(String method) {

        this.method = method;
        return this;
    }

    /**
     * Get method
     *
     * @return method
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getMethod() {
        return method;
    }

    @JsonProperty(JSON_PROPERTY_METHOD)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMethod(String method) {
        this.method = method;
    }

    public InlineHookOAuthBasicConfig uri(String uri) {

        this.uri = uri;
        return this;
    }

    /**
     * Get uri
     *
     * @return uri
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_URI)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getUri() {
        return uri;
    }

    @JsonProperty(JSON_PROPERTY_URI)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setUri(String uri) {
        this.uri = uri;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        InlineHookOAuthBasicConfig inlineHookOAuthBasicConfig = (InlineHookOAuthBasicConfig) o;
        return Objects.equals(this.authType, inlineHookOAuthBasicConfig.authType)
                && Objects.equals(this.clientId, inlineHookOAuthBasicConfig.clientId)
                && Objects.equals(this.scope, inlineHookOAuthBasicConfig.scope)
                && Objects.equals(this.tokenUrl, inlineHookOAuthBasicConfig.tokenUrl)
                && Objects.equals(this.authScheme, inlineHookOAuthBasicConfig.authScheme)
                && Objects.equals(this.headers, inlineHookOAuthBasicConfig.headers)
                && Objects.equals(this.method, inlineHookOAuthBasicConfig.method)
                && Objects.equals(this.uri, inlineHookOAuthBasicConfig.uri);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(authType, clientId, scope, tokenUrl, authScheme, headers, method, uri);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class InlineHookOAuthBasicConfig {\n");
        sb.append("    authType: ").append(toIndentedString(authType)).append("\n");
        sb.append("    clientId: ").append(toIndentedString(clientId)).append("\n");
        sb.append("    scope: ").append(toIndentedString(scope)).append("\n");
        sb.append("    tokenUrl: ").append(toIndentedString(tokenUrl)).append("\n");
        sb.append("    authScheme: ").append(toIndentedString(authScheme)).append("\n");
        sb.append("    headers: ").append(toIndentedString(headers)).append("\n");
        sb.append("    method: ").append(toIndentedString(method)).append("\n");
        sb.append("    uri: ").append(toIndentedString(uri)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
